#!/bin/bash
#online or offline
style=$1 
enabled=$2
repo_address=$3

clean()
{
	/usr/sbin/yum-complete-transaction --cleanup-only
	sleep 1
	yum clean dbcache rpmdb
}

update_system()
{
	yum clean dbcache rpmdb
	sleep 1
	yum update -y
	if [ $? == "0" ];then
		exit 0
	else
		exit -1
	fi
}

write_offline_repo()
{
echo "[neokylin-offline]
name=NeoKylin-offline - \$basearch
baseurl=$1
enabled=$2
gpgcheck=0
skip_if_unavailable = 1
keepcache = 0" > /etc/yum.repos.d/offline.repo
}

write_online_repo()
{
echo "[Neokylin-online]
name=NeoKylin-online - \$basearch
baseurl=$1
enabled=$2
gpgcheck=0
skip_if_unavailable = 1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-neokylin-mips64el" > /etc/yum.repos.d/online.repo
}

change_default_repo()
{
sed -i "s/enabled=[0-9]/enabled=$1/g" /etc/yum.repos.d/neokylin.repo
sed -i "s/enabled=[0-9]/enabled=$1/g" /etc/yum.repos.d/neokylin-updates.repo
}

set_update_alarm()
{
	sed -i "/$3\ export\ DISPLAY\=\:0\ &&\ \/usr\/bin\/neokylin\-auto\-update/d" /etc/crontab

	if [ $2 -eq -1 ];then
		echo "0 $1 * * * $3 export DISPLAY=:0 && /usr/bin/neokylin-auto-update" >> /etc/crontab
	else
		echo "0 $1 * * $2 $3 export DISPLAY=:0 && /usr/bin/neokylin-auto-update" >> /etc/crontab
	fi

	systemctl restart crond
}

set_update_alarm_check()
{
	sed -i "/$3\ export\ DISPLAY\=\:0\ &&\ \/usr\/bin\/neokylin\-auto\-update/d" /etc/crontab

	if [ $2 -eq -1 ];then
		echo "0 $1 * * * $3 export DISPLAY=:0 && /usr/bin/neokylin-auto-update --check" >> /etc/crontab
	else
		echo "0 $1 * * $2 $3 export DISPLAY=:0 && /usr/bin/neokylin-auto-update --check" >> /etc/crontab
	fi

	systemctl restart crond
}

cancel_update_alarm()
{
	sed -i "/$1\ export\ DISPLAY\=\:0\ &&\ \/usr\/bin\/neokylin\-auto\-update/d" /etc/crontab
}

SYSTEM=`uname -m`
s_version=
if [ $SYSTEM = "mips64el" -o $SYSTEM = "mips64" ];then
	online_url=http://download.cs2c.com.cn/neokylin/server/updates/x.2/ls_64/os
elif [ $SYSTEM = "sw_64" ];then
	online_url=http://10.3.6.75/kojifiles/repos/nd7-sw_64-Release-build/latest/sw_64
elif [ $SYSTEM = "x86_64" ];then
	s_version=`cat /etc/.productinfo|sed -n '2,2p'|grep '5.0'`
	if [ "X"$s_version != "X" ];then
		online_url=http://download.cs2c.com.cn/neokylin/desktop/releases/5.1/x86_64/os/
	else
		online_url=http://download.cs2c.com.cn/neokylin/desktop/releases/7.1/x86_64/os/
	fi
elif [ $SYSTEM = "i686" -o $SYSTEM = "i386" ];then
	s_version=`cat /etc/.productinfo|sed -n '2,2p'|grep '5.0'`
	if [ "X"$s_version != "X" ];then
		online_url=http://download.cs2c.com.cn/neokylin/desktop/releases/5.1/i386/os/
	else
		online_url=http://download.cs2c.com.cn/neokylin/desktop/releases/7.1/i386/os/
	fi
else
	online_url=http://
fi

offline_url=file:///opt/update/



if [ $1 = "on" ];then
	if [ "X$3" = "X" ];then
		write_online_repo ${online_url} $2
	else
		write_online_repo $3 $2
	fi
elif [ $1 = "off" ];then
	if [ "X$3" = "X" ];then
		write_offline_repo ${offline_url} $2
		createrepo /opt/update
	else
		write_offline_repo $3 $2
	fi
elif [ $1 = "default" ];then
	change_default_repo $2
elif [ $1 = "alarm" ];then
	set_update_alarm $2 $3 $4
elif [ $1 = "cancel" ];then
	cancel_update_alarm $2
elif [ $1 = "update-all" ];then
	update_system
elif [ $1 = "alarm-check" ];then
	set_update_alarm_check $2 $3 $4
elif [ $1 = "clean" ];then
	clean
else
	yum clean dbcache rpmdb
	echo "Please enter the params like on;off;default"
fi

exit 0

#yum clean all

